Struct amazon_sp_finances::models::capacity_reservation_billing_event::CapacityReservationBillingEvent
source · [−]pub struct CapacityReservationBillingEvent {
pub transaction_type: Option<String>,
pub posted_date: Option<String>,
pub description: Option<String>,
pub transaction_amount: Option<Box<Currency>>,
}Expand description
CapacityReservationBillingEvent : An event related to a capacity reservation billing charge.
Fields
transaction_type: Option<String>Indicates the type of transaction. Example: "FBA Inventory Fee"
posted_date: Option<String>description: Option<String>A short description of the capacity reservation billing event.
transaction_amount: Option<Box<Currency>>Implementations
sourceimpl CapacityReservationBillingEvent
impl CapacityReservationBillingEvent
sourcepub fn new() -> CapacityReservationBillingEvent
pub fn new() -> CapacityReservationBillingEvent
An event related to a capacity reservation billing charge.